@@ -19,6 +19,16 @@ from pycoMeth import __name__ as pkg_name
 # Third party imports
 import colorlog
 
+# Optional static export deps
+try:
+    from kaleido.scopes.plotly import PlotlyScope
+    from IPython.core.display import SVG, display
+    STATIC_EXPORT=True
+except (ModuleNotFoundError, ImportError) as E:
+    print("Cannot import dependencies required for static image export")
+    STATIC_EXPORT=False
+    pass
+
 #~~~~~~~~~~~~~~FUNCTIONS~~~~~~~~~~~~~~#
 def opt_summary (local_opt):
     """Simplifiy option dict creation"""
@@ -97,6 +107,10 @@ def dict_to_str (d, sep="\t", nsep=0, exclude_list=[]):
     else:
         return m[:-1]
 
+def iter_idx_tuples (df):
+    for idx, line in zip(df.index, df.itertuples(index=False, name='line')):
+        yield (idx, line)
+
 def doc_func (func):
     """Parse the function description string"""
 
@@ -363,6 +377,31 @@ def log_list (l, logger, header="", indent="\t"):
     for i in l:
         logger("{}*{}".format(indent, i))
 
+
+class Kaleido:
+    def __init__ (self):
+        # Init scopes
+        if not STATIC_EXPORT:
+            raise ImportError ("Static export is not possible due to missing dependencies")
+        self.plotly_scope = PlotlyScope()
+
+    def render_plotly_svg (self, fig, width=None, height=None):
+        """
+        Function to render a plotly figure in SVG inside jupyter
+        """
+        if STATIC_EXPORT:
+            svg_fig = self.plotly_scope.transform(fig, format="svg", width=width, height=height)
+            return SVG(svg_fig)
+
+    def export_plotly_svg (self, fig, fn, width=None, height=None):
+        """
+        Function to export a plotly figure to SVG
+        """
+        if STATIC_EXPORT:
+            svg_fig = self.plotly_scope.transform(fig, format="svg", width=width, height=height)
+            with open (fn, mode="wb") as fp:
+                fp.write(svg_fig)
+
 #~~~~~~~~~~~~~~CUSTOM EXCEPTION AND WARN CLASSES~~~~~~~~~~~~~~#
 class pycoMethError (Exception):
     """ Basic exception class for pycoMeth package """
